**Example 1: 删除应用更新触发器**



Input: 

```
tccli tcr DeleteApplicationTriggerPersonal --cli-unfold-argument  \
    --TriggerName test2
```

Output: 
```
{
    "Response": {
        "RequestId": "26358c69-7254-41e8-8f4e-bb13836e4165"
    }
}
```

